"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.oneTrust = void 0;
const analytics_consent_tools_1 = require("@segment/analytics-consent-tools");
const onetrust_api_1 = require("../lib/onetrust-api");
const oneTrust = (analytics, options = {}) => (0, analytics_consent_tools_1.createWrapper)({
    shouldLoad: async () => {
        await (0, analytics_consent_tools_1.resolveWhen)(() => {
            const oneTrustGlobal = (0, onetrust_api_1.getOneTrustGlobal)();
            return (oneTrustGlobal !== undefined &&
                Boolean((0, onetrust_api_1.getConsentedGroupIds)().length) &&
                oneTrustGlobal.IsAlertBoxClosed());
        }, 500);
    },
    getCategories: () => {
        // so basically, if a user has 2 categories defined in the UI: [Functional, Advertising],
        // we need _all_ those categories to be valid
        // Scenarios:
        // - if the user is being asked to select categories, so the popup is still visible
        // - if user has no categories selected because they deliberately do not consent to anything and the popup has been dismissed in this session
        // - if user has selected categories in a past session
        // - if the user has selected categories this session
        // - if user has no categories selected because they deliberately do not consent to anything and the popup was dismissed in a previous session
        const { userSetConsentGroups, userDeniedConsentGroups } = (0, onetrust_api_1.getGroupData)();
        const consentedCategories = userSetConsentGroups.reduce((acc, c) => {
            return {
                ...acc,
                [c.groupName]: true,
                [c.customGroupId]: true,
            };
        }, {});
        const deniedCategories = userDeniedConsentGroups.reduce((acc, c) => {
            return {
                ...acc,
                [c.groupName]: false,
                [c.customGroupId]: false,
            };
        }, {});
        return { ...consentedCategories, ...deniedCategories };
    },
    integrationCategoryMappings: options.integrationCategoryMappings,
})(analytics);
exports.oneTrust = oneTrust;
//# sourceMappingURL=wrapper.js.map