"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGroupData = exports.getConsentedGroupIds = exports.getOneTrustGlobal = void 0;
/**
 * @example
 * ",CAT001,FOO456" => ["CAT001", "FOO456"]
 */
const normalizeActiveGroupIds = (c) => c.trim().split(',').filter(Boolean);
const getOneTrustGlobal = () => window.OneTrust;
exports.getOneTrustGlobal = getOneTrustGlobal;
const getOneTrustActiveGroups = () => window.OnetrustActiveGroups;
const getConsentedGroupIds = () => {
    const groups = getOneTrustActiveGroups();
    if (!groups) {
        return [];
    }
    return normalizeActiveGroupIds(groups || '');
};
exports.getConsentedGroupIds = getConsentedGroupIds;
const normalizeGroupInfo = (groupInfo) => ({
    customGroupId: groupInfo.CustomGroupId.trim(),
    groupName: groupInfo.GroupName.trim(), // should we allow groupName?
});
/**
 * get *all* groups / categories, not just active ones
 */
const getAllGroups = () => {
    const oneTrustGlobal = (0, exports.getOneTrustGlobal)();
    if (!oneTrustGlobal)
        return [];
    return oneTrustGlobal.GetDomainData().Groups.map(normalizeGroupInfo);
};
// derive the groupIds from the active groups
const getGroupData = () => {
    const userSetConsentGroupIds = (0, exports.getConsentedGroupIds)();
    // partition all groups into "consent" or "deny"
    const userConsentGroupData = getAllGroups().reduce((acc, group) => {
        if (userSetConsentGroupIds.includes(group.customGroupId)) {
            acc.userSetConsentGroups.push(group);
        }
        else {
            acc.userDeniedConsentGroups.push(group);
        }
        return acc;
    }, { userSetConsentGroups: [], userDeniedConsentGroups: [] });
    return userConsentGroupData;
};
exports.getGroupData = getGroupData;
//# sourceMappingURL=onetrust-api.js.map